==> openGion_dev_5.9.14.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF66S.sql <==
/****************************************************************************/
/* GF66 ( ﾀｽｸﾘｿｰｽ定義 )                                                     */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF66 (
   PRJCODE      varchar           ( 30 )                                        /*  10 PRJｺｰﾄﾞ  */
 , TASK_ID      INTEGER                                                         /*  20 ﾀｽｸID    */
 , RESOURCE_ID  INTEGER                                                         /*  30 ﾘｿｰｽID   */
 , SEQ          INTEGER                         DEFAULT 0   NOT NULL            /*  40 順       */
 , SU_LOAD      INTEGER                                                         /*  50 負荷     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (  1 )        DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           ( 14 )                                        /* 820 登録日時 */
 , PGSET        varchar           ( 10 )                                        /* 830 作成PG   */
 , PGPSET       varchar           ( 10 )                                        /* 840 作成親PG */
 , USRSET       varchar           ( 10 )                                        /* 850 作成社員 */
 , DYUPD        varchar           ( 14 )                                        /* 860 更新日時 */
 , PGUPD        varchar           ( 10 )                                        /* 870 更新PG   */
 , PGPUPD       varchar           ( 10 )                                        /* 880 更新親PG */
 , USRUPD       varchar           ( 10 )                                        /* 890 更新者   */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF66S.sql <==
/****************************************************************************/
/* GF66 ( ﾀｽｸﾘｿｰｽ定義 )                                                     */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF66 (
   PRJCODE      varchar           ( 30 )                                        /*  10 PRJｺｰﾄﾞ  */
 , TASK_ID      INTEGER                                                         /*  20 ﾀｽｸID    */
 , RESOURCE_ID  INTEGER                                                         /*  30 ﾘｿｰｽID   */
 , SEQ          INTEGER                         DEFAULT 0   NOT NULL            /*  40 順       */
 , SU_LOAD      INTEGER                                                         /*  50 負荷     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (  1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           ( 14 )                                        /* 820 登録日時 */
 , PGSET        varchar           ( 10 )                                        /* 830 作成PG   */
 , PGPSET       varchar           ( 10 )                                        /* 840 作成親PG */
 , USRSET       varchar           ( 10 )                                        /* 850 作成社員 */
 , DYUPD        varchar           ( 14 )                                        /* 860 更新日時 */
 , PGUPD        varchar           ( 10 )                                        /* 870 更新PG   */
 , PGPUPD       varchar           ( 10 )                                        /* 880 更新親PG */
 , USRUPD       varchar           ( 10 )                                        /* 890 更新者   */
);
